summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgamepropertyhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgamepropertyhandler.h')
-rw-r--r--libkdegames/kgame/kgamepropertyhandler.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkdegames/kgame/kgamepropertyhandler.h b/libkdegames/kgame/kgamepropertyhandler.h
index df9a66cb..c2a3429f 100644
--- a/libkdegames/kgame/kgamepropertyhandler.h
+++ b/libkdegames/kgame/kgamepropertyhandler.h
@@ -43,8 +43,8 @@ class KGamePropertyHandlerPrivate; // wow - what a name ;-)
* to care about the KGamePropertHandler. KGame and KPlayer implement
* all features of KGamePropertyHandler so you will rather use it there.
*
* You have to use the KGamePropertyHandler as tqparent for all KGameProperty
* objects but you can also use KPlayer or KGame as tqparent - then
* KPlayer::dataHandler or KGame::dataHandler will be used.
*
* Every KGamePropertyHandler must have - just like every KGameProperty -
@@ -81,18 +81,18 @@ public:
* You have to call registerHandler before you can use this
* handler!
**/
- KGamePropertyHandler(TQObject* tqparent = 0);
+ KGamePropertyHandler(TQObject* parent = 0);
/**
* Construct a registered handler.
*
* @see registerHandler
**/
- KGamePropertyHandler(int id, const TQObject* receiver, const char* sendf, const char* emitf, TQObject* tqparent = 0);
+ KGamePropertyHandler(int id, const TQObject* receiver, const char* sendf, const char* emitf, TQObject* parent = 0);
~KGamePropertyHandler();
/**
* Register the handler with a tqparent. This is to use
* if the constructor without arguments has been chosen.
* Otherwise you need not call this.
*
@@ -106,7 +106,7 @@ public:
/**
* Main message process function. This has to be called by
* the tqparent's message event handler. If the id of the message
* agrees with the id of the handler, the message is extracted
* and processed. Otherwise false is returned.
* Example:
@@ -170,7 +170,7 @@ public:
/**
* called by a property to send itself into the
* datastream. This call is simply forwarded to
* the tqparent object
**/
bool sendProperty(TQDataStream &s);
@@ -179,7 +179,7 @@ public:
/**
* called by a property to emit a signal
* This call is simply forwarded to
* the tqparent object
**/
void emitSignal(KGamePropertyBase *data);
@@ -316,7 +316,7 @@ signals:
/**
* This signal is emitted when a property needs to be sent. Only the
* tqparent has to react to this.
* @param msgid The id of the handler
* @param sent set this to true if the property was sent successfully -
* otherwise don't touch
@@ -43,8 +43,8 @@ class KGamePropertyHandlerPrivate; // wow - what a name ;-)
* all features of KGamePropertyHandler so you will rather use it there.
*
- * You have to use the KGamePropertyHandler as tqparent for all KGameProperty
- * objects but you can also use KPlayer or KGame as tqparent - then
+ * You have to use the KGamePropertyHandler as parent for all KGameProperty
+ * objects but you can also use KPlayer or KGame as parent - then
* KPlayer::dataHandler or KGame::dataHandler will be used.
*
@@ -81,18 +81,18 @@ public:
~KGamePropertyHandler();
/**
- * Register the handler with a tqparent. This is to use
+ * Register the handler with a parent. This is to use
* if the constructor without arguments has been chosen.
* Otherwise you need not call this.
@@ -106,7 +106,7 @@ public:
/**
* Main message process function. This has to be called by
- * the tqparent's message event handler. If the id of the message
+ * the parent's message event handler. If the id of the message
* agrees with the id of the handler, the message is extracted
* and processed. Otherwise false is returned.
@@ -170,7 +170,7 @@ public:
* called by a property to send itself into the
* datastream. This call is simply forwarded to
- * the tqparent object
+ * the parent object
**/
bool sendProperty(TQDataStream &s);
@@ -179,7 +179,7 @@ public:
* called by a property to emit a signal
* This call is simply forwarded to
- * the tqparent object
+ * the parent object
**/
void emitSignal(KGamePropertyBase *data);
@@ -316,7 +316,7 @@ signals:
/**
* This signal is emitted when a property needs to be sent. Only the
- * tqparent has to react to this.
+ * parent has to react to this.
* @param msgid The id of the handler
* @param sent set this to true if the property was sent successfully -